bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift C ## 28. Aventiure
___________________________________________________ #### Auenture wie die Nibelunge ze Ezeln bvrge chomen #### vn– wie si da enpfangen wrden
| ### <Do> die Nibelunge chomen in daz lant ### do vrieschez von <Berne> meister Hildebrant ### ez sagtez sime herren ez was im grimme leit ### er bat in wol enpfahen die chvnen ritter gemeit ### Do hiez der starche Wolfhart bringen in div march ### do reit mit Dietriche vil manic reche starch ### da si se enpfa[62r]hen wolden zvo zin an daz velt ### da hetens vf gebunden vil manic herlich gezelt
###### 1760 | ### Do si von Tronege Hagene verrest chomen sach ### zv den sinen herren der helt vil balde sprach ### nv svlt ir snellen degene von dem sedele stan ### vn– get in hin begegene die ivch hie wellent enpfan
###### 1761 | ### Dort chvmt her ein gesinde daz ist mir wol bechant ### ez sint vil snelle degene von Amelvnge lant ### die fvret der von Berne si sint vil hochgemvot ### ir svltz in wol erbieten daz rat ich sprach der degen gvot
###### 1762 | ### Do stvnden von den rossen daz was vil michel reht ### nider mit Dietriche manic ritter vn– kneht ### si giengen zv den gesten da man die helede vant ### si grvzten minnekliche die von Bvregonden lant
| ### Do si der herre Dietrich zvo zin chomen sach ### beide liebe vnde leide im dar an geschach ### er weste wol div mære ir reise was im leit ### er wande ez weste Rvdeger daz erz het in geseit
###### 1764 | ### Sit willechomen her Gunther Gernot vn– Giselher ### Hagen vn– Danchwart sam si ovch Volker ### vn– allez iwr gedigene den Sivrides tot ### weinet min froe Chriemh' noch diche in angestlicher not
###### 1765 | ### Si mac vil geweinen sprach do Hagene ### er lit vor manigem iare ze tode erslagene ### den kunech von den Hvnen den si genomen hat ### den sol si nv minnen Sivrit so gahes niht erstat
###### 1766 | ### Tot des chunen rechen lazen wir nv sten ### sol lebn min froe Chriemh' noch mac schade ergen ### so redete von Berne der herre bieterich ### trost der Nibelunge da vor behvet dv dich
###### 1767 | ### Wie sol ich mich behvten sprach der kunic her ### Ezel vns boten sande wes sol ich vragen mer ### daz wir zvo zim chomen her in siniv lant ### oech hat vns vnser swester aller triwen gemant
| ### So wil ich iv wol raten sprach do Hagene ### nv bitet iv div mære baz ze sagene ### den herren Dietrichen vn– sine helde gvot ### daz si ivch lazen wizzen der frowen Chriemh' mvot
###### 1769 | ### Do giengen svndersprachen die dri kunige rich ### Gunther unde Gernot vn– ovch her Dietrich ### nv sage vns von Berne vil edel ritter gvot ### wie dir si gewizzen der frowen Chriemh' mvot
###### 1770 | ### Do sprach der vogt von Berne waz sol ich iv mere sagen ### wan alle morgen frveie weinen un– klagen ### hoere ich vil iæmerliche daz Ezeln wip ### dem richen got von himele des starchen Sivrides lip
###### 1771 | ### Ez ist et vnerwendet sprach do der spileman ### Volker der vil chvene daz wir vernomen han ### wir svln ze hove riten vn– svln daz besehn ### waz vns snellen degenen mvge zen Hvnen geschehn
###### 1772 | ### Die chunin Burgonden hin ze hove riten ### si chomen herrenliche nach ir landes siten ### do [62v]wndert da zen Hvnin vil manigen chvnen man ### vmbe Hagenen von Tronege wie der wære getan
###### 1773 | ### Dvrch daz man saget mære des was im genvoc ### daz er von Niderlanden Sivriden slvoc ### sterchist aller rechen den Chriemh' man ### des wart michel vragen ze hove nach Hagenen getan
| ### Der helt was wol gewahsen daz ist al war ### groz was er zen brvsten gemischet was sin har ### mit einer grisen varwe div bein im warn lanc ### vn eyslich sin gesihene er het herlichen ganc
###### 1775 | ### Do hiez man herbergen vil manigen chvnen man ### daz gesinde von dem Rine wart gesvndert dan ### daz riet div kuniginne div in argen willen trvoch ### da von man sit die knehte an der herberge slvoch
###### 1776 | ### Danchwart Hagenen brvder der was marschalch ### der kunec im sin gesinde vil vlizeklich bevalch ### daz er ir vollechliche mit spise solde pflegen ### daz tet do willechliche mit triwen der vil chvne degen
###### 1777 | ### Chriemh' div kuniginne mit ir gesinde gie ### da si die Nibelvnge in valschem mvte enpfie ### si chvste Giselhere vn– nam in bi der hant ### do daz gesach Hagene den helm er vaster gebant
###### 1778 | ### Nach svs getanem grvoze sprach do Hagene ### mvgen sich bedenchen wol snelle degene ### man grvzet sunderlingen die fvrsten un– ir man ### wir han niht gvter reise zv dirre hochgecite getan
| ### Nv sit sprach si willechomen swer ivch gerne siht ### dvrch iwer selbes frivntschaft engrvz ich ivch niht ### nv sagt waz ir mir bringet von Wormez vber Rin ### dar vmbe ir mir so groze soldet willechomen sin
###### 1780 | ### Het ich gewist div mære sprach do Hagene ### daz iv gabe bringen solden degene ### ich wære wol so riche het ich mihs baz verdaht ### daz ich iv mine gabe her zen Hvnen hete braht
###### 1781 | ### Nv svlt ir mich der mære mere wizzen lan ### hort der Nibelunge wa habt ir den getan ### der was idoch min eigen daz ist iv wol bechant ### den solt ir mir gefveret han her in Ezelen lant
###### 1782 | ### Entriwen min frov Chriemh' des ist vil manic tac ### deich hort der Nibelunge niene gepflach ### den hiezen mine herren senchenin den Rin ### da mvoz er wætliche vnz an daz ivngeste sin
###### 1783 | ### Do sprach div <kuneginne> ich hans ovch ê gedaht ### mir ist sin harte chleine noch her ze lande braht ### swer min eigen wære vn– ich sin wilen pflac ### nach im vn– sime herren han ich vil manigen leiden tac
###### 1784 | ### Daz ist verlorn arebeit sprach aber Hagene ### wie mohte ich iv iht bringen iclh han vil ze tragene ### an <halsperge> vn– an schilte an mime helme lieht ### diz swert an miner hende des enbringe ich iv nieht
###### 1785 | ### Iane rede ihz niht darvmbe deich mere goldes wel[63r]le gern ### ich hans so vil ze gebene deich iwer gabe mac enbern ### ein mort vn– zwene rovbe die mir sint genomen ### des mohte ich vil arme noch ze liebem gelte chomen
| ### Div frowe hiez do chunden den rechen vber al ### daz niemen tragen solde dehein wafen in den sal ### ir helde ir svlt mirs vf geben ich sol si behalten lan ### entriwen sprach do Hagene daz wirdet nimmer getan
###### 1787 | ### Iane ger ich niht der eren fvrsten wine milt ### daz ir zen herbergen trvget minen schilt ### vn– ander min gewæfen ir sit ein kunigin ### daz enlerte mich vater niht ich wil selbe kamerære sin
###### 1788 | ### Owe mir der leide sprach do Chriemh' ### warvmbe wil min brvder vn– Hagen sinen schilt ### von in niht tragen lazen si sint gewarnot ### vn– wesse ich wer iz tæte ich riet im immer sinen tot
###### 1789 | ### Des antwort in zorne der herre Dietrich ### ich binz der hat gewarnet die edeln fvrsten rich ### vn– Hagenen den starchen den Buregonden man ### nv zvo vahendinne dv solt mihs niht geniezen lan
| ### Des schamte sich vil sere daz Ezelen wip ### si vorhte bitterliche den Dietriches lip ### do gie si von in dannen daz si niht mere ensprach ### wan daz si swinde bliche an ir viande sach
###### 1791 | ### Bi henden sich do viengen zwene degene ### daz eine was her Dietrich daz ander Hagene ### do sprach gezogenliche der reche vil gemeit ### daz iwer chomen zen Hvnen daz ist mir grozelichen leit
###### 1792 | ### Do stvnden bi ein ander die rechen lobelich ### Hagene von Tronege vn– oech her Dietrich ### in grozen zvhten manigen die ritter wolgetan ### daz sach der kunec Ezele darvmbe er vragen do began
###### 1793 | ### Div mære ich wiste gerne sprach der kunic rich ### wer iener reche wære den dort her Dietrich ### so frivntlich enpfæhet er treit vil hohen mvot ### swer sin vater wære er mach wol sin ein helt gvot
| ### Des antwrtem kunige ein Chriemh' man ### er ist geborn von Tronege sin vater hiez Adrian ### swie blider hie gebarte er ist ein grimmer man ### ich laze ivch daz wol schowen daz ich gelogen niene han
###### 1795 | ### Wie sol ich daz erchennen daz er so grimmech ist ### noch dann er niht enwiste vil manigen argen list ### den div kvniginne an ir frivnden begie ### daz si ir mit dem lebene niht einen dannen chomen lie
###### 1796 | ### Wol erchande ich Adrianen der was min man ### lob vn– michel ere er hie bi mir gewan ### ich machet in ze ritter vn– gab im min golt ### Helche div getriwe was im inneklichen holt
###### 1797 | ### Da von ich wol erchenne allez Hagenen sint ### ez wrden mine gisel zwei wætlichiv kint ### er vn– von Spane Walther die wohsen hie ze man ### Hagenen sande ich widere Walther mit Hiltegunde entran
###### 1798 | ### Er [63v]gedahte langer mære div warn ê geschehn ### siner frivnt von Tronege den het er reht ersehn ### der im in siner ivgende vil starchen dienest bot ### sit frvmter im in alter vil manigen frivnt tot

<<< Übersicht <<< vorige Seite nächste Seite >>>